proxy

package
v0.0.0-...-28b0f66 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 13, 2017 License: MIT, Zlib Imports: 16 Imported by: 0

Documentation

Index

Constants

const (
	// ErrDockerContainerIdentifierNotFound defines an error raised when DockM is unable to find a container identifier
	ErrDockerContainerIdentifierNotFound = dockm.Error("Docker container identifier not found")
)
const (
	// ErrDockerServiceIdentifierNotFound defines an error raised when dockm is unable to find a service identifier
	ErrDockerServiceIdentifierNotFound = dockm.Error("Docker service identifier not found")
)
const (
	// ErrDockerVolumeIdentifierNotFound defines an error raised when DockM is unable to find a volume identifier
	ErrDockerVolumeIdentifierNotFound = dockm.Error("Docker volume identifier not found")
)
const (
	// ErrEmptyResponseBody defines an error raised when dockm excepts to parse the body of a HTTP response and there is nothing to parse
	ErrEmptyResponseBody = dockm.Error("Empty response body")
)

Variables

This section is empty.

Functions

This section is empty.

Types

type Manager

type Manager struct {
	// contains filtered or unexported fields
}

Manager represents a service used to manage Docker proxies.

func NewManager

func NewManager(resourceControlService dockm.ResourceControlService, teamMembershipService dockm.TeamMembershipService, settingsService dockm.SettingsService) *Manager

NewManager initializes a new proxy Service

func (*Manager) CreateAndRegisterProxy

func (manager *Manager) CreateAndRegisterProxy(endpoint *dockm.Endpoint) (http.Handler, error)

CreateAndRegisterProxy creates a new HTTP reverse proxy and adds it to the registered proxies. It can also be used to create a new HTTP reverse proxy and replace an already registered proxy.

func (*Manager) DeleteProxy

func (manager *Manager) DeleteProxy(key string)

DeleteProxy deletes the proxy associated to a key

func (*Manager) GetProxy

func (manager *Manager) GetProxy(key string) http.Handler

GetProxy returns the proxy associated to a key

Jump to