Documentation
¶
Index ¶
Constants ¶
const (
// ErrDockerContainerIdentifierNotFound defines an error raised when DockM is unable to find a container identifier
ErrDockerContainerIdentifierNotFound = dockm.Error("Docker container identifier not found")
)
const (
// ErrDockerServiceIdentifierNotFound defines an error raised when dockm is unable to find a service identifier
ErrDockerServiceIdentifierNotFound = dockm.Error("Docker service identifier not found")
)
const (
// ErrDockerVolumeIdentifierNotFound defines an error raised when DockM is unable to find a volume identifier
ErrDockerVolumeIdentifierNotFound = dockm.Error("Docker volume identifier not found")
)
const (
// ErrEmptyResponseBody defines an error raised when dockm excepts to parse the body of a HTTP response and there is nothing to parse
ErrEmptyResponseBody = dockm.Error("Empty response body")
)
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Manager ¶
type Manager struct {
// contains filtered or unexported fields
}
Manager represents a service used to manage Docker proxies.
func NewManager ¶
func NewManager(resourceControlService dockm.ResourceControlService, teamMembershipService dockm.TeamMembershipService, settingsService dockm.SettingsService) *Manager
NewManager initializes a new proxy Service
func (*Manager) CreateAndRegisterProxy ¶
CreateAndRegisterProxy creates a new HTTP reverse proxy and adds it to the registered proxies. It can also be used to create a new HTTP reverse proxy and replace an already registered proxy.
func (*Manager) DeleteProxy ¶
DeleteProxy deletes the proxy associated to a key
Click to show internal directories.
Click to hide internal directories.